(function (exports) {
'use strict';

var Mouse = function () {
  function Mouse(enabled, speed) {
    babelHelpers.classCallCheck(this, Mouse);

    this.config = { aceleration: speed || 2 };
    AFRAME.components['look-controls'].Component.prototype.updateOrientation = this.register;
  }

  babelHelpers.createClass(Mouse, [{
    key: 'register',
    value: function register(enabled, speed) {
      var el = this.el;
      var hmdEuler = this.hmdEuler;
      var pitchObject = this.pitchObject;
      var yawObject = this.yawObject;
      var sceneEl = this.el.sceneEl;
      var q = this.q = this.q || new THREE.Quaternion();

      if (sceneEl.is('vr-mode') && sceneEl.checkHeadsetConnected()) {
        return;
      }

      var rotationComponent = el.components.rotation;
      if (rotationComponent) {
        hmdEuler.set(THREE.Math.DEG2RAD * rotationComponent.data.x, THREE.Math.DEG2RAD * rotationComponent.data.y, THREE.Math.DEG2RAD * rotationComponent.data.z, 'YXZ');
        q.setFromEuler(hmdEuler);
        hmdEuler.setFromQuaternion(q, 'YXZ');
      } else {
        hmdEuler.setFromQuaternion(this.polyfillObject.quaternion, 'YXZ');
      }
      el.object3D.rotation.x = -1 * (hmdEuler.x + pitchObject.rotation.x);
      el.object3D.rotation.y = -1 * (hmdEuler.y + yawObject.rotation.y);
      el.object3D.rotation.z = 0;
    }
  }, {
    key: 'update',
    value: function update(value) {
      var _ref = void 0;
      if ((_ref = AFRAME.components[this.NAME]) != null && 10 > value ? _ref.schema != null : false) {
        _ref.schema.speed.default = value / 10;
      }
    }
  }]);
  return Mouse;
}();

var Aframe = function (_akamai$amp$Plugin) {
  babelHelpers.inherits(Aframe, _akamai$amp$Plugin);

  function Aframe(player, config) {
    babelHelpers.classCallCheck(this, Aframe);

    var _this = babelHelpers.possibleConstructorReturn(this, (Aframe.__proto__ || Object.getPrototypeOf(Aframe)).call(this, player, config));

    _this.container = player.container;
    _this.scene = document.createElement("a-scene");
    _this.sphere = document.createElement("a-videosphere");
    _this.sky = document.createElement("a-sky"); // 360 poster image
    _this.scene.setAttribute("vr-mode-ui", "enabled: " + _this.isCompatible());
    _this.sphere.setAttribute("rotation", _this.config.data.rotation || "0 180 0");
    _this.pattern = typeof config.data.pattern != 'undefined' ? new RegExp(config.data.pattern, "i") : new RegExp("360", "i");
    _this.pattern = config.data.strict ? _this.pattern : new RegExp("", "i");

    if (config.mouse != null && config.mouse.speed) {
      _this.mouse = new Mouse(true, config.mouse.speed);
    }
    return _this;
  }

  babelHelpers.createClass(Aframe, [{
    key: "onready",
    value: function onready(event) {
      this.initComponent();
      this.player.addEventListener("mediachange", this.onMediaChangeHandler.bind(this));
    }
  }, {
    key: "onMediaChangeHandler",
    value: function onMediaChangeHandler() {
      var media = this.player.media !== null ? this.player.media : this.player.getMedia();
      var hasSphereElement = this.scene.getChildEntities().indexOf(this.sphere) > -1;
      var hasSkyElement = this.scene.getChildEntities().indexOf(this.sky) > -1;
      var category = typeof media.category != 'undefined' ? media.category : "";

      switch (media.medium) {
        case 'audio':
          this.sky.setAttribute("src", media.poster);
          this.scene.appendChild(this.sky);
          this.player.setDisplayState('aframe-sky');
          if (hasSphereElement) this.scene.removeChild(this.sphere);
          break;
        default:
          if (this.pattern.test(category)) {
            this.player.setDisplayState('aframe-sphere');
            if (hasSkyElement) this.scene.removeChild(this.sky);
            this.scene.appendChild(this.sphere);
          } else {
            this.player.setDisplayState('non-sphere');
            if (hasSphereElement) this.scene.removeChild(this.sphere);
          }
          break;
      }
    }
  }, {
    key: "initComponent",
    value: function initComponent() {
      this.player.mediaElement.setAttribute("id", "videoamp"); // adding id to video player for sphere src reference
      this.sphere.setAttribute("src", "#videoamp");
      this.scene.appendChild(this.sphere);

      var layer = document.createElement("div");
      layer.className = "amp-vr";
      layer.appendChild(this.scene);

      //append a-frame scene to player
      this.container.appendChild(layer);
    }
  }, {
    key: "updateMouseSpeed",
    value: function updateMouseSpeed(value) {
      if (this.mouse) {
        this.mouse.update(value);
      }
    }
  }, {
    key: "isCompatible",
    value: function isCompatible() {
      var compatible = typeof navigator.getVRDisplays == "function";
      if (compatible === false) {
        console.log("Your browser is not compatible with A-Frame check this page out https://get.webgl.org/");
      }
      return compatible;
    }
  }]);
  return Aframe;
}(akamai.amp.Plugin);

akamai.amp.AMP.registerPlugin("aframe", typeof akamai.amp.Plugin.createFactory == 'function' ? akamai.amp.Plugin.createFactory(Aframe) : Aframe.factory);

exports.Aframe = Aframe;

}((this.akamai.amp.aframe = this.akamai.amp.aframe || {})));
//# sourceMappingURL=Aframe.js.map
